//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IKokushiHandPattern](index.md)/[yaochu](yaochu.md)

# yaochu

[common]\
abstract val [yaochu](yaochu.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;

幺九牌
